pub fn query_state_exclusive_solution_set(
tx: &Transaction<'_>,
contract_ca: &ContentAddress,
key: &Key,
block_address: &ContentAddress,
solution_set_index: u64,
) -> Result<Option<Value>, QueryError>Expand description
Query for the most recent version value of a key in a contracts state that was set at or before the given block address and before the solution set index (within that block).
This is exclusive of the solution set’s state ..=block_address[..solution_set_index].