pub fn query_state_inclusive_block(
conn: &Connection,
contract_ca: &ContentAddress,
key: &Key,
block_address: &ContentAddress,
) -> Result<Option<Value>, QueryError>Expand description
Query the most recent value for a key in a contract’s state that was set at or before the given block address.
This is inclusive of the block’s state (..=block_address).