query_state_inclusive_solution_set

Function query_state_inclusive_solution_set 

pub fn query_state_inclusive_solution_set(
    conn: &Connection,
    contract_ca: &ContentAddress,
    key: &Key,
    block_address: &ContentAddress,
    solution_set_index: u64,
) -> Result<Option<Value>, QueryError>
Query for the most recent version value of a key in a contracts state that was set at or before the given block address and solution set index (within that block).

This is inclusive of the solution’s state mutations ..=block_address[..=solution_set_index]