pub fn get_next_block_addresses(
conn: &Connection,
current_block: &ContentAddress,
) -> Result<Vec<ContentAddress>, QueryError>Expand description
Given a block address, returns the addresses of blocks that have the next block number.
pub fn get_next_block_addresses(
conn: &Connection,
current_block: &ContentAddress,
) -> Result<Vec<ContentAddress>, QueryError>Given a block address, returns the addresses of blocks that have the next block number.