pub fn query_state_exclusive_block(
tx: &Transaction<'_>,
contract_ca: &ContentAddress,
key: &Key,
block_address: &ContentAddress,
) -> Result<Option<Value>, QueryError>Expand description
Query for the most recent version value of a key in a contracts state that was set before the given block number.
This is exclusive of the block’s state (..block_address).